@@ -1,6 +1,9 @@
+import logging
+
 from elf_to_shellcode.lib.shellcode import Shellcode, create_make_shellcode
-from elftools.elf.enums import ENUM_RELOC_TYPE_AARCH64
+from elf_to_shellcode.arm.aarch64_dynamic_relocations import AArch64DynamicRelocations
 from elf_to_shellcode.lib.ext.irelative_relocations import IrelativeRelocs
+from elftools.elf.enums import ENUM_RELOC_TYPE_AARCH64
 
 
 # Refernce: https://static1.squarespace.com/static/59c4375b8a02c798d1cce06f/t/59d55a7bf5e2319471bb94a4/1507154557709/ELF+for+ARM64.pdf
@@ -22,22 +25,23 @@ class ArmX64Shellcode(Shellcode):
             support_dynamic=False,
             **kwargs
         )
-        self.irelative = IrelativeRelocs(ENUM_RELOC_TYPE_AARCH64['R_AARCH64_TLS_DTPMOD32'])
-        self.add_relocation_handler(self.irelative.relocation_for_rela_plt_got_plt)
+        self.dynamic_handler = AArch64DynamicRelocations(shellcode=self)
+        self.add_relocation_handler(self.dynamic_handler.handle)
+
+    def shellcode_handle_padding(self, shellcode_data):
+        dummy_header = self.shellcode_get_full_header(padding=0x0)
 
-    def build_shellcode_from_header_and_code(self, header, code):
         # Now we are going to align our shellcode
         aarch64_alignment = (2 << 12)
-        if len(header) > aarch64_alignment:
-            alignment = len(header) % aarch64_alignment
+        if len(dummy_header) > aarch64_alignment:
+            alignment = len(dummy_header) % aarch64_alignment
         else:
-            alignment = aarch64_alignment - len(header)
+            alignment = aarch64_alignment - len(dummy_header)
         padding = b'\x00' * alignment
-        header_moved = self.move_header_by_offset(header,
-                                                  offset=len(padding))
-
-        constructed = header_moved + padding + code
-        return constructed
+        logging.info("Aarch64 add alignment: {}".format(
+            hex(alignment)
+        ))
+        return alignment, padding + shellcode_data
 
 
 arm_x64_make_shellcode = create_make_shellcode(ArmX64Shellcode)
