@@ -3,8 +3,11 @@ import os
 base_file = os.path.dirname(__file__)
 
 
-def get_resource(resource_name):
-    path = get_resource_path(resource_name)
+def get_resource(resource_name, resolve=True):
+    if resolve:
+        path = get_resource_path(resource_name)
+    else:
+        path = resource_name
     with open(path, "rb") as fp:
         return fp.read()
 
